@@ -1,3 +1,5 @@
+import datetime
+
 from je_api_testka.requests_wrapper.requests_data_structure import api_tester_method
 from requests.structures import CaseInsensitiveDict
 
@@ -37,30 +39,25 @@ exception_message_dict = {
 }
 
 
-def get_response(response, get_json: bool = False):
-    if get_json:
-        response_data = {
-            "status_code": response.status_code,
-            "json_data": response.json()
-        }
-        return response_data
-    else:
-        try:
-            return get_api_response_data(response)
-        except APITesterGetDataException:
-            raise APITesterGetDataException(api_test_get_data_error_message)
+def get_response(response, start_time, end_time):
+    try:
+        return get_api_response_data(response, start_time, end_time)
+    except APITesterGetDataException:
+        raise APITesterGetDataException(api_test_get_data_error_message)
 
 
-def test_api_method(http_method: str, test_url: str, get_json: bool = False,
+def test_api_method(http_method: str, test_url: str,
                     soap: bool = False, record_request_info: bool = True,
                     clean_record: bool = False, **kwargs):
+    start_time = datetime.datetime.now()
     if soap is False:
         response = api_tester_method(http_method, test_url=test_url, **kwargs)
     else:
         headers = CaseInsensitiveDict()
         headers["Content-Type"] = "application/soap+xml"
         return test_api_method(http_method, test_url=test_url, headers=headers, **kwargs)
-    response_data = get_response(response, get_json)
+    end_time = datetime.datetime.now()
+    response_data = get_response(response, start_time, end_time)
     if record_request_info:
         record.record_list.append(response_data)
     elif clean_record:
